@@ -180,7 +180,7 @@ static s32 lzp_decode_block(const u8 * RESTRICT in, const u8 * in_end, s32 * RES
 
                 const u8 * ref = outs + val;
                 u8 * oe = out + len;
-                if (oe > out_end) return -1;
+                if (oe > out_end) oe = out_end;
 
                 while (out < oe) *out++ = *ref++;
 
@@ -685,7 +685,7 @@ BZIP3_API s32 bz3_decode_block(struct bz3_state * state, u8 * buffer, s32 data_s
 
     // Undo LZP
     if (model & 2) {
-        size_src = lzp_decompress(b1, b2, lzp_size, state->block_size, state->lzp_lut);
+        size_src = lzp_decompress(b1, b2, lzp_size, bz3_bound(state->block_size), state->lzp_lut);
         if (size_src == -1) {
             state->last_error = BZ3_ERR_CRC;
             return -1;
